package com.iohao.mmo.excel.controller;

import com.alibaba.excel.EasyExcel;
import com.iohao.mmo.common.kit.Result;
import com.iohao.mmo.equip.entity.EquipEntry;
import com.iohao.mmo.equip.entity.EquipEntryTemplate;
import com.iohao.mmo.excel.dto.DemoExcelDTO;
import com.iohao.mmo.excel.dto.EquipEntryTemplateExcelDTO;
import com.iohao.mmo.excel.kit.ExcelKit;
import com.iohao.mmo.excel.listener.EquipEntryTemplateExcelListener;
import com.iohao.mmo.excel.listener.ExcelAnalysisHelper;
import com.iohao.mmo.excel.listener.ExcelDataCustomListener;
import com.iohao.mmo.excel.service.EquipEntryTemplateExcelService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import lombok.AllArgsConstructor;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import java.util.List;
import java.util.Map;

/**
 * 装备excel数据
 * @author 唐斌
 * @date 2023-08-29
 */
@AllArgsConstructor
@RestController
@RequestMapping("/equipexcel")
@Tag(name = "EquipExcelController", description = "装备excel数据")
public class EquipExcelController {
    private final EquipEntryTemplateExcelService equipEntryTemplateExcelService;

    /**
     * 导出
     * @param params
     * @param response
     * @throws Exception
     */
    @Operation(summary = "导出",description = "导出")
    @GetMapping("exportExcel")
    public void exportExcel(@RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception{
        List<EquipEntryTemplate> list = equipEntryTemplateExcelService.list(params,EquipEntryTemplate.class);
        ExcelKit.exportExcelToTarget(response, null, "装备词条", list, EquipEntryTemplateExcelDTO.class);
    }

    /**
     * 导入数据自定义处理示例
     * @param file
     * @return
     * @throws Exception
     */
    @PostMapping(value = "importExcel", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    @Operation(summary = "导入数据自定义处理示例",description = "导入数据自定义处理示例")
    public Result importExcel(@RequestPart("file") @Parameter(description = "文件")MultipartFile file) throws Exception {
        //自定义读取
        EasyExcel.read(file.getInputStream(), EquipEntryTemplateExcelDTO.class, new EquipEntryTemplateExcelListener<>(equipEntryTemplateExcelService,2)).sheet(0).doRead();
//        ExcelAnalysisHelper excelAnalysisHelper = new ExcelAnalysisHelper();
//        List<EquipEntryTemplateExcelDTO> list = excelAnalysisHelper.getList(file.getInputStream(), EquipEntryTemplateExcelDTO.class);
//        list.forEach(System.out::println);
        return new Result().ok("导入成功！");
    }
}
